
.. blogpost::
    :title: Module xray was renamed into xarray
    :keywords: arrays, xray, xarray
    :date: 2016-03-12
    :categories: module

    Module *xray* was renamed into
    `xarray <http://xarray.pydata.org/en/stable/index.html>`_.
    The reason:

        This avoids a namespace conflict with the entire field of x-ray science.
